Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(894)

Unified Diff: content/public/browser/devtools_frontend_host.h

Issue 744653002: Ignore DevTools messages from the old inspected RVH after navigation (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed comment Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/devtools_frontend_host.h
diff --git a/content/public/browser/devtools_frontend_host.h b/content/public/browser/devtools_frontend_host.h
index 24c50f51e07b1e61ac22fb15c40db11c36d65f22..d1b01fe537a1c5d2f196483130520f5ee8c6d665 100644
--- a/content/public/browser/devtools_frontend_host.h
+++ b/content/public/browser/devtools_frontend_host.h
@@ -11,7 +11,7 @@
namespace content {
-class RenderViewHost;
+class WebContents;
// This class dispatches messages between DevTools frontend and Delegate
// which is implemented by the embedder.
@@ -35,10 +35,11 @@ class DevToolsFrontendHost {
const std::string& message) = 0;
};
// Creates a new DevToolsFrontendHost for RenderViewHost where DevTools
// frontend is loaded.
CONTENT_EXPORT static DevToolsFrontendHost* Create(
- RenderViewHost* frontend_rvh, Delegate* delegate);
+ WebContents* frontend_web_contents,
+ Delegate* delegate);
CONTENT_EXPORT virtual ~DevToolsFrontendHost() {}
};
« no previous file with comments | « content/browser/devtools/render_view_devtools_agent_host.cc ('k') | content/renderer/devtools/devtools_agent.h » ('j') | no next file with comments »
@@ -35,10 +35,11 @@ class DevToolsFrontendHost {
const std::string& message) = 0;
};
- // Creates a new DevToolsFrontendHost for RenderViewHost where DevTools
+ // Creates a new DevToolsFrontendHost for WebContents where DevTools
// frontend is loaded.
CONTENT_EXPORT static DevToolsFrontendHost* Create(

Powered by Google App Engine
This is Rietveld 408576698